package tools.descartes.dql.connector.kieker.structures.cpu;

import java.util.ArrayList;

import tools.descartes.dql.connector.kieker.structures.AbstractValue;
import tools.descartes.dql.connector.kieker.structures.ResourceContent;
import tools.descartes.dql.connector.kieker.structures.ResourceContent.ResourceContentType;

public class CpuMapValue extends AbstractValue<ResourceContent> {
	
	public CpuMapValue(long timestamp,long interval, Double totalUtilization, Double nice,Double idle, Double wait, Double irq){
		//System.out.println(interval +", "+ totalUtilization +", "+ nice +", "+ idle  +", "+ wait +", "+ irq);
		ResourceContent content = new ResourceContent(ResourceContentType.CPU);
		content.set(ResourceContent.TIME_INTERVAL, (double) interval);
		content.set(ResourceContent.UTILIZATION, totalUtilization);
		content.set(ResourceContent.NICE, nice);
		content.set(ResourceContent.IDLE, idle);
		content.set(ResourceContent.WAIT, wait);
		content.set(ResourceContent.IRQ, irq);
		super.put(timestamp, content);
	}

	public CpuMapValue(long timestamp, ResourceContent content){
		super.put(timestamp, content);
	}


	/**
	 * This method enhances information that shares the same CpuMapKey.
	 * Thus it should only be invoked to do so.
	 * 
	 * @param executionTime describes the term from start to termination of the Cpu
	 * @return CpuMapValue which contains the new updated information
	 */
	public synchronized CpuMapValue enhance(long timestamp, ResourceContent content){
		super.put(timestamp, content);
		return this;
	}


	/**
	 * This method returns an array of type Long including all execution times.
	 * @return Long[]
	 */
	public ArrayList<TimeDataPair<Long, ResourceContent>> getExecutionTimeArrayList() {
		return super.getArrayList();
	}

	@Override
	public String toString(){
		StringBuilder builder = new StringBuilder();
		for (TimeDataPair<Long, ResourceContent> pair : super.getArrayList()) {
			builder.append("\t TOTAL [");
			builder.append(String.format("%2.18f", pair.getData().get(ResourceContent.UTILIZATION)));
			builder.append("] \t| INTERVAL: ");
			builder.append(String.format("%.0f", pair.getData().get(ResourceContent.TIME_INTERVAL)));
			builder.append(" \t| NICE: ");
			builder.append(String.format("%2.18f", pair.getData().get(ResourceContent.NICE)));
			builder.append(" \t| IDLE: ");
			builder.append(String.format("%2.18f", pair.getData().get(ResourceContent.IDLE)));
			builder.append(" \t| WAIT: ");
			builder.append(String.format("%2.18f", pair.getData().get(ResourceContent.WAIT)));
			builder.append(" \t| IRQ: ");
			builder.append(String.format("%2.18f", pair.getData().get(ResourceContent.IRQ)));
			builder.append(" \t|");
			builder.append(String.format("$%d", pair.getTime()));
		}
		return builder.toString();
	}



}
